@@ -65,10 +65,7 @@ class GradeNotebooks():
 class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
                                tornado.auth.GoogleOAuth2Mixin):
     async def get(self):
-        log.write_logs("1.", str(self.current_user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        log.write_logs("2.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')    
         if not self.get_argument('code', False):
-            log.write_logs("3.", str(self.current_user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
             self.authorize_redirect(
                 redirect_uri='http://grader-dev.data8x.berkeley.edu/login',
                 client_id=self.settings['google_oauth']['key'],
@@ -80,25 +77,13 @@ class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
         user = await self.get_authenticated_user(
                         redirect_uri='http://grader-dev.data8x.berkeley.edu/login',
                         code=self.get_argument('code'))
-        # Save the user with e.g. set_secure_cookie
-        log.write_logs("4.", str(user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
         self.set_secure_cookie("user", str(user))
 
-        log.write_logs("5.", str(self.current_user), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
         self.redirect("/")
     
 class Userform(BaseHandler, tornado.web.RequestHandler):
     @tornado.web.authenticated
-    async def get(self):
-        # c = self.get_secure_cookie("user")
-        # log.write_logs("1.", str(c), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        # log.write_logs("2.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        
-        # if not self.get_current_user():
-        #     self.redirect("/login")
-        #     return
-        
-        log.write_logs("6.", "Authenticated!", "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
+    async def get(self): 
         self.render("index.html",  message=None)
 
 class Download(BaseHandler, tornado.web.RequestHandler):
@@ -178,7 +163,7 @@ settings = {
         "key": os.environ.get("OAUTH_CLIENT_ID"),
         "secret": os.environ.get("OAUTH_SECRET")
     },
-    "login_url": "/login",
+    "login_url": "/login"
 }
 application = tornado.web.Application([
         (r"/", Userform),
